==> distribution-6.0.0-dev.128.zip: drr/regulation/mas/rewrite/valuation/reports/MASValuationReportFunction.java <==
package drr.regulation.mas.rewrite.valuation.reports;

import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.annotations.RosettaReport;
import com.rosetta.model.lib.annotations.RuneLabelProvider;
import com.rosetta.model.lib.functions.ModelObjectValidator;
import com.rosetta.model.lib.reports.ReportFunction;
import drr.regulation.common.ValuationReportInstruction;
import drr.regulation.mas.rewrite.valuation.MASValuationReport;
import drr.regulation.mas.rewrite.valuation.MASValuationReport.MASValuationReportBuilder;
import drr.regulation.mas.rewrite.valuation.labels.MASValuationLabelProvider;
import java.util.Optional;
import javax.inject.Inject;


@RosettaReport(namespace="drr.regulation.mas.rewrite.valuation", body="MAS", corpusList={"Valuation"})
@RuneLabelProvider(labelProvider=MASValuationLabelProvider.class)
@ImplementedBy(MASValuationReportFunction.MASValuationReportFunctionDefault.class)
public abstract class MASValuationReportFunction implements ReportFunction<ValuationReportInstruction, MASValuationReport> {
	
	@Inject protected ModelObjectValidator objectValidator;
	
	// RosettaFunction dependencies
	//
	@Inject protected ActionTypeRule actionTypeRule;
	@Inject protected Counterparty1Rule counterparty1Rule;
	@Inject protected Counterparty2IdentifierTypeRule counterparty2IdentifierTypeRule;
	@Inject protected Counterparty2Rule counterparty2Rule;
	@Inject protected DataSubmitterRule dataSubmitterRule;
	@Inject protected ExecutionAgentOfCounterparty1DTCCRule executionAgentOfCounterparty1DTCCRule;
	@Inject protected ExecutionAgentOfCounterparty2DTCCRule executionAgentOfCounterparty2DTCCRule;
	@Inject protected ReportingSpecifiedPersonRule reportingSpecifiedPersonRule;
	@Inject protected ReportingTimestampRule reportingTimestampRule;
	@Inject protected TechnicalRecordIdRule technicalRecordIdRule;
	@Inject protected UniqueTransactionIdentifierProprietaryRule uniqueTransactionIdentifierProprietaryRule;
	@Inject protected UniqueTransactionIdentifierRule uniqueTransactionIdentifierRule;
	@Inject protected ValuationAmountRule valuationAmountRule;
	@Inject protected ValuationCurrencyRule valuationCurrencyRule;
	@Inject protected ValuationMethodRule valuationMethodRule;
	@Inject protected ValuationTimestampRule valuationTimestampRule;

	/**
	* @param input 
	* @return output 
	*/
	@Override
	public MASValuationReport evaluate(ValuationReportInstruction input) {
		MASValuationReport.MASValuationReportBuilder outputBuilder = doEvaluate(input);
		
		final MASValuationReport output;
		if (outputBuilder == null) {
			output = null;
		} else {
			output = outputBuilder.build();
			objectValidator.validate(MASValuationReport.class, output);
		}
		
		return output;
	}

	protected abstract MASValuationReport.MASValuationReportBuilder doEvaluate(ValuationReportInstruction input);

	public static class MASValuationReportFunctionDefault extends MASValuationReportFunction {
		@Override
		protected MASValuationReport.MASValuationReportBuilder doEvaluate(ValuationReportInstruction input) {
			MASValuationReport.MASValuationReportBuilder output = MASValuationReport.builder();
			return assignOutput(output, input);
		}
		
		protected MASValuationReport.MASValuationReportBuilder assignOutput(MASValuationReport.MASValuationReportBuilder output, ValuationReportInstruction input) {
			output
				.setUniqueTransactionIdentifier(uniqueTransactionIdentifierRule.evaluate(input));
			
			output
				.setUniqueTransactionIdentifierProprietary(uniqueTransactionIdentifierProprietaryRule.evaluate(input));
			
			output
				.setReportingSpecifiedPerson(reportingSpecifiedPersonRule.evaluate(input));
			
			output
				.setCounterparty1(counterparty1Rule.evaluate(input));
			
			output
				.setCounterparty2(counterparty2Rule.evaluate(input));
			
			output
				.setCounterparty2IdentifierType(counterparty2IdentifierTypeRule.evaluate(input));
			
			output
				.setActionType(actionTypeRule.evaluate(input));
			
			output
				.setReportingTimestamp(reportingTimestampRule.evaluate(input));
			
			output
				.setDataSubmitter(dataSubmitterRule.evaluate(input));
			
			output
				.setValuationTimestamp(valuationTimestampRule.evaluate(input));
			
			output
				.setValuationAmount(valuationAmountRule.evaluate(input));
			
			output
				.setValuationCurrency(valuationCurrencyRule.evaluate(input));
			
			output
				.setValuationMethod(valuationMethodRule.evaluate(input));
			
			output
				.setTechnicalRecordId(technicalRecordIdRule.evaluate(input));
			
			output
				.setExecutionAgentOfTheCounterparty1(executionAgentOfCounterparty1DTCCRule.evaluate(input));
			
			output
				.setExecutionAgentOfTheCounterparty2(executionAgentOfCounterparty2DTCCRule.evaluate(input));
			
			return Optional.ofNullable(output)
				.map(o -> o.prune())
				.orElse(null);
		}
	}
}

==> distribution-7.0.0-dev.92.zip: drr/regulation/mas/rewrite/valuation/reports/MASValuationReportFunction.java <==
package drr.regulation.mas.rewrite.valuation.reports;

import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.annotations.RosettaReport;
import com.rosetta.model.lib.annotations.RuneLabelProvider;
import com.rosetta.model.lib.functions.ModelObjectValidator;
import com.rosetta.model.lib.reports.ReportFunction;
import drr.regulation.common.ValuationReportInstruction;
import drr.regulation.common.valuation.datetime.reports.ReportingTimestampRule;
import drr.regulation.common.valuation.datetime.reports.ValuationTimestampRule;
import drr.regulation.common.valuation.event.reports.ActionTypeRule;
import drr.regulation.common.valuation.event.reports.LevelRule;
import drr.regulation.common.valuation.party.reports.Counterparty1Rule;
import drr.regulation.common.valuation.party.reports.Counterparty2IdentifierTypeRule;
import drr.regulation.common.valuation.party.reports.Counterparty2Rule;
import drr.regulation.common.valuation.party.reports.EntityResponsibleForReportingRule;
import drr.regulation.common.valuation.party.reports.ReportSubmittingEntityIDRule;
import drr.regulation.common.valuation.valuation.reports.ValuationAmountRule;
import drr.regulation.common.valuation.valuation.reports.ValuationCurrencyRule;
import drr.regulation.common.valuation.valuation.reports.ValuationMethodRule;
import drr.regulation.mas.rewrite.valuation.MASValuationReport;
import drr.regulation.mas.rewrite.valuation.labels.MASValuationLabelProvider;
import java.util.Optional;
import javax.inject.Inject;


@RosettaReport(namespace="drr.regulation.mas.rewrite.valuation", body="MAS", corpusList={"Valuation"})
@RuneLabelProvider(labelProvider=MASValuationLabelProvider.class)
@ImplementedBy(MASValuationReportFunction.MASValuationReportFunctionDefault.class)
public abstract class MASValuationReportFunction implements ReportFunction<ValuationReportInstruction, MASValuationReport> {
	
	@Inject protected ModelObjectValidator objectValidator;
	
	// RosettaFunction dependencies
	//
	@Inject protected ActionTypeRule actionTypeRule;
	@Inject protected Counterparty1Rule counterparty1Rule;
	@Inject protected Counterparty2IdentifierTypeRule counterparty2IdentifierTypeRule;
	@Inject protected Counterparty2Rule counterparty2Rule;
	@Inject protected EntityResponsibleForReportingRule entityResponsibleForReportingRule;
	@Inject protected ExecutionAgentOfCounterparty1DTCCRule executionAgentOfCounterparty1DTCCRule;
	@Inject protected ExecutionAgentOfCounterparty2DTCCRule executionAgentOfCounterparty2DTCCRule;
	@Inject protected LevelRule levelRule;
	@Inject protected ReportSubmittingEntityIDRule reportSubmittingEntityIDRule;
	@Inject protected ReportingTimestampRule reportingTimestampRule;
	@Inject protected TechnicalRecordIdRule technicalRecordIdRule;
	@Inject protected UniqueTransactionIdentifierProprietaryRule uniqueTransactionIdentifierProprietaryRule;
	@Inject protected UniqueTransactionIdentifierRule uniqueTransactionIdentifierRule;
	@Inject protected ValuationAmountRule valuationAmountRule;
	@Inject protected ValuationCurrencyRule valuationCurrencyRule;
	@Inject protected ValuationMethodRule valuationMethodRule;
	@Inject protected ValuationTimestampRule valuationTimestampRule;

	/**
	* @param input 
	* @return output 
	*/
	@Override
	public MASValuationReport evaluate(ValuationReportInstruction input) {
		MASValuationReport.MASValuationReportBuilder outputBuilder = doEvaluate(input);
		
		final MASValuationReport output;
		if (outputBuilder == null) {
			output = null;
		} else {
			output = outputBuilder.build();
			objectValidator.validate(MASValuationReport.class, output);
		}
		
		return output;
	}

	protected abstract MASValuationReport.MASValuationReportBuilder doEvaluate(ValuationReportInstruction input);

	public static class MASValuationReportFunctionDefault extends MASValuationReportFunction {
		@Override
		protected MASValuationReport.MASValuationReportBuilder doEvaluate(ValuationReportInstruction input) {
			MASValuationReport.MASValuationReportBuilder output = MASValuationReport.builder();
			return assignOutput(output, input);
		}
		
		protected MASValuationReport.MASValuationReportBuilder assignOutput(MASValuationReport.MASValuationReportBuilder output, ValuationReportInstruction input) {
			output
				.setReportingTimestamp(reportingTimestampRule.evaluate(input));
			
			output
				.setCounterparty1(counterparty1Rule.evaluate(input));
			
			output
				.setCounterparty2IdentifierTypeOverriddenAsBoolean(counterparty2IdentifierTypeRule.evaluate(input));
			
			output
				.setCounterparty2(counterparty2Rule.evaluate(input));
			
			output
				.setValuationAmount(valuationAmountRule.evaluate(input));
			
			output
				.setValuationCurrency(valuationCurrencyRule.evaluate(input));
			
			output
				.setValuationTimestamp(valuationTimestampRule.evaluate(input));
			
			output
				.setValuationMethod(valuationMethodRule.evaluate(input));
			
			output
				.setActionType(actionTypeRule.evaluate(input));
			
			output
				.setLevel(levelRule.evaluate(input));
			
			output
				.setTechnicalRecordId(technicalRecordIdRule.evaluate(input));
			
			output
				.setReportSubmittingEntityIDOverriddenAsString(reportSubmittingEntityIDRule.evaluate(input));
			
			output
				.setEntityResponsibleForReporting(entityResponsibleForReportingRule.evaluate(input));
			
			output
				.setUniqueTransactionIdentifier(uniqueTransactionIdentifierRule.evaluate(input));
			
			output
				.setUniqueTransactionIdentifierProprietary(uniqueTransactionIdentifierProprietaryRule.evaluate(input));
			
			output
				.setExecutionAgentOfTheCounterparty1(executionAgentOfCounterparty1DTCCRule.evaluate(input));
			
			output
				.setExecutionAgentOfTheCounterparty2(executionAgentOfCounterparty2DTCCRule.evaluate(input));
			
			return Optional.ofNullable(output)
				.map(o -> o.prune())
				.orElse(null);
		}
	}
}
